@@ -468,7 +468,7 @@ bool fishProtocol::connectionStart() {
         } else {
             #define common_args "-l", connectionUser.toLatin1().constData(), "-x", "-e", "none", \
                     "-q", connectionHost.toLatin1().constData(),        \
-                "echo FISH:;exec /bin/sh -c \"if env true 2>/dev/null; then env PS1= PS2= TZ=UTC LANG=C LC_ALL=C LOCALE=C /bin/sh; else PS1= PS2= TZ=UTC LANG=C LC_ALL=C LOCALE=C /bin/sh; fi\"", (void *)0
+                "echo FISH:;exec /bin/sh -c \"if env true 2>/dev/null; then env PS1= PS2= TZ=UTC LANG=C LC_ALL=C LOCALE=C /bin/sh; else PS1= PS2= TZ=UTC LANG=C LC_ALL=C LOCALE=C /bin/sh; fi\"", (void *)nullptr
             // disabled: leave compression up to the client.
             // (isOpenSSH?"-C":"+C"),
 
@@ -947,15 +947,15 @@ void fishProtocol::manageConnection(const QString &l) {
                     if (line[9] == 'w') accessVal |= S_IWOTH;
                     if (line[10] == 'x' || line[10] == 't') accessVal |= S_IXOTH;
                     if (line[10] == 'T' || line[10] == 't') accessVal |= S_ISVTX;
-                    udsEntry.insert(KIO::UDSEntry::UDS_ACCESS, accessVal);
+                    udsEntry.replace(KIO::UDSEntry::UDS_ACCESS, accessVal);
 
                     pos = line.indexOf(':',12);
                     if (pos < 0) {
                         errorCount++;
                         break;
                     }
-                    udsEntry.insert(KIO::UDSEntry::UDS_USER, line.mid(12,pos-12));
-                    udsEntry.insert(KIO::UDSEntry::UDS_GROUP, line.mid(pos+1));
+                    udsEntry.replace(KIO::UDSEntry::UDS_USER, line.mid(12,pos-12));
+                    udsEntry.replace(KIO::UDSEntry::UDS_GROUP, line.mid(pos+1));
                 }
                 break;
 
@@ -964,8 +964,8 @@ void fishProtocol::manageConnection(const QString &l) {
                     pos2 = line.indexOf(' ',pos+1);
                     if (pos < 0 || pos2 < 0) break;
                     errorCount--;
-                    udsEntry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME,
-                                    makeTimeFromLs(line.mid(1,pos-1), line.mid(pos+1,pos2-pos), line.mid(pos2+1)));
+                    udsEntry.replace(KIO::UDSEntry::UDS_MODIFICATION_TIME,
+                                     makeTimeFromLs(line.mid(1,pos-1), line.mid(pos+1,pos2-pos), line.mid(pos2+1)));
                     break;
 
                 case 'D':
@@ -980,7 +980,7 @@ void fishProtocol::manageConnection(const QString &l) {
                     if (pos < 0 || pos2 < 0 || pos3 < 0) break;
                     dt.setTime(QTime(line.mid(pos+1,pos2-pos-1).toInt(),line.mid(pos2+1,pos3-pos2-1).toInt(),line.mid(pos3+1).toInt()));
                     errorCount--;
-                    udsEntry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME, dt.toTime_t());
+                    udsEntry.replace(KIO::UDSEntry::UDS_MODIFICATION_TIME, dt.toTime_t());
                     break;
 
                 case 'S':
@@ -988,7 +988,7 @@ void fishProtocol::manageConnection(const QString &l) {
                     long long sizeVal = line.mid(1).toLongLong(&isOk);
                     if (!isOk) break;
                     errorCount--;
-                    udsEntry.insert(KIO::UDSEntry::UDS_SIZE, sizeVal);
+                    udsEntry.replace(KIO::UDSEntry::UDS_SIZE, sizeVal);
                 }
                 break;
 
@@ -1000,7 +1000,7 @@ void fishProtocol::manageConnection(const QString &l) {
                     pos = line.lastIndexOf('/');
                     thisFn = line.mid(pos < 0?1:pos+1);
                     if (fishCommand == FISH_LIST) {
-                        udsEntry.insert(KIO::UDSEntry::UDS_NAME, thisFn);
+                        udsEntry.replace(KIO::UDSEntry::UDS_NAME, thisFn);
                     }
                     // By default, the mimetype comes from the extension
                     // We'll use the file(1) result only as fallback [like the rest of KDE does]
@@ -1028,17 +1028,17 @@ void fishProtocol::manageConnection(const QString &l) {
                     break;
 
                 case 'L':
-                    udsEntry.insert(KIO::UDSEntry::UDS_LINK_DEST, line.mid(1));
+                    udsEntry.replace(KIO::UDSEntry::UDS_LINK_DEST, line.mid(1));
                     if (!udsType) udsType = S_IFLNK;
                     errorCount--;
                     break;
                 }
             } else {
                 if (!udsMime.isNull())
-                    udsEntry.insert(KIO::UDSEntry::UDS_MIME_TYPE, udsMime);
+                    udsEntry.replace(KIO::UDSEntry::UDS_MIME_TYPE, udsMime);
                 udsMime.clear();
 
-                udsEntry.insert( KIO::UDSEntry::UDS_FILE_TYPE, udsType );
+                udsEntry.replace( KIO::UDSEntry::UDS_FILE_TYPE, udsType );
                 udsType = 0;
 
                 if (fishCommand == FISH_STAT)
@@ -1186,7 +1186,7 @@ void fishProtocol::manageConnection(const QString &l) {
                 return; // Don't call finished!
             }
         } else if (fishCommand == FISH_STAT) {
-            udsStatEntry.insert( KIO::UDSEntry::UDS_NAME, url.fileName() );
+            udsStatEntry.replace( KIO::UDSEntry::UDS_NAME, url.fileName() );
             statEntry(udsStatEntry);
         } else if (fishCommand == FISH_APPEND) {
             dataReq();
