@@ -372,12 +372,12 @@ QString ThumbnailProtocol::pluginForMimeType(const QString& mimeType) {
     //Match group mimetypes
     ///@todo Move this into some central location together with the related matching code in previewjob.cpp. This doesn't handle inheritance and such
     const KService::List plugins = KServiceTypeTrader::self()->query("ThumbCreator");
-    foreach(KService::Ptr plugin, plugins) {
+    for (const KService::Ptr& plugin : plugins) {
         const QStringList mimeTypes = plugin->serviceTypes();
-        foreach(QString mime, mimeTypes) {
+        for (const QString& mime : mimeTypes) {
             if(mime.endsWith('*')) {
-                mime = mime.left(mime.length()-1);
-                if(mimeType.startsWith(mime))
+                const auto mimeGroup = mime.leftRef(mime.length()-1);
+                if(mimeType.startsWith(mimeGroup))
                     return plugin->library();
             }
         }
